@@ -456,6 +456,9 @@ char mdi[], mzi[], mdj[], mzj[];
       if(strstr(mdj+1, "men")) return;
       else if(strstr("he,she,it", mdj+1) || strstr(mzj, "") == 0 || strchr(mzj, 'z') ){
     if(Dbg == 'Y') fprintf(dbg, "--- ninsyo --- 2 %s \n", mdj+1);
+        if(strcmp(mdi+1, "often happen") == 0){
+	  ptreplace(mdi+1, 12, "often happens");  return;
+        }
         if((pt = (char*)strchr(mdi, ' ')) || (pt = (char*)strchr(mdi, '\0'))){
           if(*(pt-1) == 'o' || *(pt-1) == 's' || *(pt-1) == 'x'
           || strncmp(pt-2, "sh", 2) == 0 || strncmp(pt-2, "ch", 2) == 0)
@@ -507,7 +510,7 @@ char mdi[], mzi[], mdj[], mzj[];
       || strncmp(mdi+1, "all", 3) == 0) return;
       if(strchr(mzi, 'K') || strstr(mdj+1, " and ") ) return;
 //  printf("--- ninsho --- mdi = %s mzi = %s \n", mdi, mzi);
-      if(strncmp(mdi+1, "a ", 2) == 0) return;
+      if(strncmp(mdi+1, "a ", 2) == 0 || strncmp(mdi+1, "an ", 3) == 0) return;
       if(strchr("aiueo", *(mdi+1))){
         ptinsert(mdi+1, "an ");
       }
