@@ -526,9 +526,12 @@ predit()
     if(pt = (char*)strstr(wdh, "܂")) ptreplace(pt, 8, "A܂");
     if(pt = (char*)strstr(wdh, "̂ł")) ptreplace(pt, 4, "/");
     if(pt = (char*)strstr(wdh, "̂Ƃ킴")) ptreplace(pt, 4, "/");
+    if(pt = (char*)strstr(wdh, "Ƃ")) ptreplace(pt, 8, "");
     if(pt = (char*)strstr(wdh, "Ƃ͂Ă")) ptreplace(pt, 14, "A");
-    if(strstr(wdh, "ǂꂭ炢") && (pt = (char*)strstr(wdh, "B"))) ptreplace(pt, 2, "H");
-    if(strstr(wdh, "Ȃ") && (pt = (char*)strstr(wdh, "B"))) ptreplace(pt, 2, "H");
+    if(strstr(wdh, "ǂꂭ炢") && (pt = (char*)strstr(wdh, "B")))
+      ptreplace(pt, 2, "H");
+    if(strstr(wdh, "Ȃ") && (pt = (char*)strstr(wdh, "B")))
+      ptreplace(pt, 2, "H");
   if(Dbg == 'Y') fprintf(dbg, "--- predit --- ܂ -> Ȃ \n");
     if(pt = (char*)strstr(wdh, "܂")){
       if(strncmp(pt, "܂", 10)) ptreplace(pt, 8, "Ȃ");
